#!/usr/bin/env node
'use strict'

const foreground = require('foreground-child')
const mkdirp = require('mkdirp')
const report = require('../lib/report')
const rimraf = require('rimraf')
const {
  hideInstrumenteeArgs,
  hideInstrumenterArgs,
  yargs
} = require('../lib/parse-args')

const instrumenterArgs = hideInstrumenteeArgs()
let argv = yargs.parse(instrumenterArgs)

if (argv._[0] === 'report') {
  argv = yargs.parse(process.argv) // support flag arguments after "report".
  outputReport()
} else {
  rimraf.sync(argv.tempDirectory)
  mkdirp.sync(argv.tempDirectory)
  process.env.NODE_V8_COVERAGE = argv.tempDirectory

  foreground(hideInstrumenterArgs(argv), () => {
    outputReport()
  })
}

function outputReport () {
  report({
    include: argv.include,
    exclude: argv.exclude,
    reporter: Array.isArray(argv.reporter) ? argv.reporter : [argv.reporter],
    tempDirectory: argv.tempDirectory,
    watermarks: argv.watermarks,
    resolve: argv.resolve
  })
}
